@@ -1,9 +1,9 @@
 /*
- * $Id: dialog.c,v 1.270 2019/07/24 23:27:01 tom Exp $
+ * $Id: dialog.c,v 1.277 2020/11/26 16:49:01 tom Exp $
  *
  *  cdialog - Display simple dialog boxes from shell scripts
  *
- *  Copyright 2000-2018,2019	Thomas E. Dickey
+ *  Copyright 2000-2019,2020	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -25,6 +25,7 @@
  */
 
 #include <dialog.h>
+
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -33,6 +34,8 @@
 #include <locale.h>
 #endif
 
+#include <dlg_internals.h>
+
 #define PASSARGS             t,       av,        offset_add
 #define CALLARGS const char *t, char *av[], int *offset_add
 typedef int (callerFn) (CALLARGS);
@@ -55,10 +58,12 @@ typedef enum {
     ,o_column_separator
     ,o_cr_wrap
     ,o_create_rc
+    ,o_cursor_off_label
     ,o_date_format
     ,o_default_button
     ,o_default_item
     ,o_defaultno
+    ,o_erase_on_exit
     ,o_exit_label
     ,o_extra_button
     ,o_extra_label
@@ -233,10 +238,12 @@ static const Options options[] = {
     { "column-separator",o_column_separator,	1, "<str>" },
     { "cr-wrap",	o_cr_wrap,		1, "" },
     { "create-rc",	o_create_rc,		1, NULL },
+    { "cursor-off-label",o_cursor_off_label,	1, "" },
     { "date-format",	o_date_format,		1, "<str>" },
     { "default-button",	o_default_button,	1, "<str>" },
     { "default-item",	o_default_item,		1, "<str>" },
     { "defaultno",	o_defaultno,		1, "" },
+    { "erase-on-exit",	o_erase_on_exit,	1, "" },
     { "exit-label",	o_exit_label,		1, "<str>" },
     { "extra-button",	o_extra_button,		1, "" },
     { "extra-label",	o_extra_label,		1, "<str>" },
@@ -619,7 +626,7 @@ lookupOption(const char *name, int pass)
 	unsigned n;
 
 	name += 2;
-	for (n = 0; n < sizeof(options) / sizeof(options[0]); n++) {
+	for (n = 0; n < TableSize(options); n++) {
 	    if ((pass & options[n].pass) != 0
 		&& !strcmp(name, options[n].name)) {
 		result = options[n].code;
@@ -1314,7 +1321,7 @@ button_code(const char *name)
     int code = DLG_EXIT_ERROR;
     size_t i;
 
-    for (i = 0; i < (sizeof(table) / sizeof(table[0])); i++) {
+    for (i = 0; i < TableSize(table); i++) {
 	if (!dlg_strcmp(name, table[i].name)) {
 	    code = table[i].code;
 	    break;
@@ -1419,7 +1426,7 @@ lookupMode(eOptions code)
     const Mode *modePtr = 0;
     unsigned n;
 
-    for (n = 0; n < sizeof(modes) / sizeof(modes[0]); n++) {
+    for (n = 0; n < TableSize(modes); n++) {
 	if (modes[n].code == code) {
 	    modePtr = &modes[n];
 	    break;
@@ -1475,7 +1482,7 @@ Help(void)
 	"Global-auto-size if also menu_height/list_height = 0.",
 	0
     };
-    size_t limit = sizeof(options) / sizeof(options[0]);
+    size_t limit = TableSize(options);
     size_t j, k;
     const Options **opts;
 
@@ -1552,7 +1559,7 @@ process_trace_option(char **argv, int *offset)
  * output stream.
  */
 static int
-process_common_options(int argc, char **argv, int offset, bool output)
+process_common_options(int argc, char **argv, int offset, int output)
 {
     bool done = FALSE;
     eOptions code;
@@ -1654,6 +1661,9 @@ process_common_options(int argc, char **argv, int offset, bool output)
 	case o_ignore:
 	    ignore_unknown = TRUE;
 	    break;
+	case o_erase_on_exit:
+	    dialog_vars.erase_on_exit = TRUE;
+	    break;
 	case o_keep_window:
 	    dialog_vars.keep_window = TRUE;
 	    break;
@@ -1743,6 +1753,9 @@ process_common_options(int argc, char **argv, int offset, bool output)
 	case o_help_label:
 	    dialog_vars.help_label = optionString(argv, &offset);
 	    break;
+	case o_cursor_off_label:
+	    dialog_vars.cursor_off_label = TRUE;
+	    break;
 	case o_date_format:
 	    dialog_vars.date_format = optionString(argv, &offset);
 	    break;
@@ -1861,7 +1874,7 @@ init_result(char *buffer)
      * environment variable.
      */
     if (first) {
-	char *env = getenv("DIALOGOPTS");
+	char *env = dlg_getenv_str("DIALOGOPTS");
 	if (env != 0)
 	    env = dlg_strclone(env);
 	if (env != 0) {
@@ -1882,9 +1895,9 @@ main(int argc, char *argv[])
     char temp[256];
     bool esc_pressed = FALSE;
     bool keep_tite = FALSE;
-    bool first_time = TRUE;
+    int initial = 1;
     int offset = 1;
-    int offset_add;
+    int offset_add = 0;
     int retval = DLG_EXIT_OK;
     int j;
     eOptions code;
@@ -1981,7 +1994,7 @@ main(int argc, char *argv[])
     }
     offset = 1;
     init_result(my_buffer);
-    dialog_vars.keep_tite = keep_tite;	/* init_result() cleared global */
+    dialog_vars.keep_tite |= keep_tite;		/* init_result() cleared global */
 
     /*
      * Dialog's output may be redirected (see above).  Handle the special
@@ -2001,6 +2014,7 @@ main(int argc, char *argv[])
 	case o_clear:
 	    initscr();
 	    refresh();
+	    dlg_keep_tite((dialog_state.output == stdout) ? stderr : stdout);
 	    endwin();
 	    break;
 	case o_ignore:
@@ -2033,8 +2047,8 @@ main(int argc, char *argv[])
 	 * which can be done before involving curses, in case we can exit
 	 * without initializing curses (and writing to the terminal).
 	 */
-	offset = process_common_options(argc, argv, offset, TRUE);
-	if (offset >= argc)
+	initial = process_common_options(argc, argv, offset, TRUE);
+	if (initial >= argc)
 	    dlg_exit(DLG_EXIT_OK);
     }
 
@@ -2044,12 +2058,8 @@ main(int argc, char *argv[])
 	int have;
 	const Mode *modePtr;
 
-	if (first_time) {
-	    first_time = FALSE;
-	} else {
-	    init_result(my_buffer);
-	    offset = process_common_options(argc, argv, offset, TRUE);
-	}
+	init_result(my_buffer);
+	offset = process_common_options(argc, argv, offset, offset > initial);
 
 	if (argv[offset] == NULL) {
 	    if (ignore_unknown)
