@@ -1,9 +1,9 @@
 /*
- *  $Id: formbox.c,v 1.97 2019/08/05 09:15:21 tom Exp $
+ *  $Id: formbox.c,v 1.102 2020/11/23 00:46:57 tom Exp $
  *
  *  formbox.c -- implements the form (i.e., some pairs label/editbox)
  *
- *  Copyright 2003-2018,2019	Thomas E. Dickey
+ *  Copyright 2003-2019,2020	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -502,7 +502,6 @@ dlg_form(const char *title,
 		 : sTEXT);
     int x, y, cur_x, cur_y, box_x, box_y;
     int code;
-    int key = 0;
     int fkey;
     int choice = dlg_default_formitem(items);
     int new_choice, new_scroll;
@@ -610,6 +609,7 @@ dlg_form(const char *title,
 
     while (result == DLG_EXIT_UNKNOWN) {
 	int edit = FALSE;
+	int key;
 
 	if (scroll_changed) {
 	    print_form(form, items, item_no, scrollamt, choice);
@@ -661,8 +661,7 @@ dlg_form(const char *title,
 
 	key = dlg_mouse_wgetch((state == sTEXT) ? form : dialog, &fkey);
 	if (dlg_result_key(key, fkey, &result)) {
-	    if (!dlg_button_key(result, &code, &key, &fkey))
-		break;
+	    break;
 	}
 
 	/* handle non-functionkeys */
@@ -701,6 +700,10 @@ dlg_form(const char *title,
 		dlg_del_window(dialog);
 		result = (state >= 0) ? dlg_enter_buttoncode(state) : DLG_EXIT_OK;
 		continue;
+	    case DLGK_LEAVE:
+		if (state >= 0)
+		    result = dlg_ok_buttoncode(state);
+		break;
 
 	    case DLGK_GRID_LEFT:
 		if (state == sTEXT)
@@ -784,10 +787,8 @@ dlg_form(const char *title,
 		height = old_height;
 		width = old_width;
 		free(prompt);
-		dlg_clear();
+		_dlg_resize_cleanup(dialog);
 		dlg_unregister_window(form);
-		dlg_del_window(dialog);
-		dlg_mouse_free_regions();
 		/* repaint */
 		goto retry;
 #endif
